@@ -12,22 +12,27 @@ __license__ = "MIT"
 __maintainer__ = "Tomas Poveda"
 __email__ = "tpovedatd@gmail.com"
 
+import maya.cmds as cmds        # Do not remove
+
 
 def init():
-    try:
-        dev = False
 
+    print('=' * 100)
+    print('| Plot Twist ArtellaPipe | > Loading Plot Twist Tools')
+
+    try:
         # Initialize tpDcc library
         import tpDcc.loader
-        tpDcc.loader.init(dev=dev)
+        print(tpDcc.loader)
+        tpDcc.loader.init(dev=False)
 
         # Initialize artellapipe library
         import artellapipe.loader
-        artellapipe.loader.init(dev=dev)
+        artellapipe.loader.init(dev=False)
 
         # Initialize plottwist project
         import plottwist.loader
-        plottwist.loader.init(dev=dev)
+        plottwist.loader.init(dev=False)
 
         print('| Plot Twist Pipeline | Plot Twist loaded successfully!')
         print('=' * 100)
@@ -37,15 +42,5 @@ def init():
         print('{} | {}'.format(exc, traceback.format_exc()))
 
 
-print('=' * 100)
-print('| Plot Twist ArtellaPipe | > Loading Plot Twist Tools')
-
-try:
-    import maya.cmds as cmds
-    cmds.evalDeferred('init()')
-    print('| Plot Twist ArtellaPipe | Plot Twist loaded successfully!')
-    print('=' * 100)
-except Exception as e:
-    init()
-    print('| Plot Twist ArtellaPipe | Plot Twist loaded successfully!')
-    print('=' * 100)
+# We must launch it with low priority, otherwise USD plugin loading operations will fail
+cmds.evalDeferred(init, lp=True)
